==> dde-network-core_1.0.64.orig.tar.xz: dde-network-core-1.0.64/dock-network-plugin/translations/dock-network-plugin_ja.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ja" version="2.1">
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>ネットワーク</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>ホットスポット</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>プロトコル</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>セキュリティタイプ</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>バンド</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>チャンネル</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>インターフェース</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>ネットマスク</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>ゲートウェイ</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>プライマリ DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>プレフィックス</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>速度</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>デバイスが無効</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>接続済み、インターネットアクセスなし</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>未接続</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>ネットワークケーブル未接続</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>接続試行中</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>認証中</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>IP アドレスを取得中</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>接続済み</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>切断</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>失敗</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>有線ネットワーク</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>有線ネットワーク %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>無線ネットワーク</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>無線接続 %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>デバイスが無効</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>ネットワークケーブル未接続</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>未接続</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>接続試行中</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>接続済み、インターネットアクセスなし</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>有線接続を無効にする</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>有線接続を有効にする</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>無線接続を無効にする</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>無線接続を有効にする</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>ネットワークを無効にする</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>ネットワークを有効にする</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>ネットワーク設定</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.5.orig.tar.xz: dde-network-core-1.1.5/dock-network-plugin/translations/dock-network-plugin_ja.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>無線ネットワーク</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>有線ネットワーク</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>ネットワーク</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>非表示のネットワークへ接続</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>パスワード</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>接続</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>ホットスポット</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>プロトコル</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>セキュリティタイプ</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>チャンネル</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>バンド</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>インターフェース</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>ネットマスク</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>ゲートウェイ</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>プライマリ DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>プレフィックス</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>速度</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>デバイスが無効</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>接続済み、インターネットアクセスなし</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>未接続</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>ネットワークケーブル未接続</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>接続試行中</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>認証中</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>IP アドレスを取得中</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>接続済み</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>切断</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>失敗</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>有線ネットワーク</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>有線ネットワーク %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>無線ネットワーク</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>無線接続 %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>デバイスが無効</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>ネットワークケーブル未接続</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>未接続</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>接続試行中</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>接続済み、インターネットアクセスなし</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>有線接続を無効にする</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>有線接続を有効にする</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>無線接続を無効にする</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>無線接続を有効にする</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>ネットワークを無効にする</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>ネットワークを有効にする</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>ネットワーク設定</translation>
    </message>
</context>
</TS>
